# Mmorpg-Scraper Changelog
## v0.0.1 - 2022-01-11
> Implemented fetch_game_details, fetch_game_list
- Initial commit for mmorpg-scraper
- fetch_game_details, fetch_game_list

## v0.0.2 - 2022-01-12
> Usage added, minor refactor.
- Readme update. Add usage.
